package javax.swing.plaf.nimbus;

import java.awt.Image;
import java.awt.Graphics;
import java.awt.Insets;

class ImageScalingHelper
{
    private static final Insets EMPTY_INSETS;
    static final int PAINT_TOP_LEFT = 1;
    static final int PAINT_TOP = 2;
    static final int PAINT_TOP_RIGHT = 4;
    static final int PAINT_LEFT = 8;
    static final int PAINT_CENTER = 16;
    static final int PAINT_RIGHT = 32;
    static final int PAINT_BOTTOM_RIGHT = 64;
    static final int PAINT_BOTTOM = 128;
    static final int PAINT_BOTTOM_LEFT = 256;
    static final int PAINT_ALL = 512;
    
    ImageScalingHelper() {
    }
    
    public static void paint(Graphics graphics, int i, int j, int n, int n2, Image image, Insets empty_INSETS, Insets empty_INSETS2, ImageScalingHelper.PaintType paintType, int n3) {
        if (image == null || image.getWidth(null) <= 0 || image.getHeight(null) <= 0) {
            return;
        }
        if (empty_INSETS == null) {
            empty_INSETS = ImageScalingHelper.EMPTY_INSETS;
        }
        if (empty_INSETS2 == null) {
            empty_INSETS2 = ImageScalingHelper.EMPTY_INSETS;
        }
        int width = image.getWidth(null);
        int height = image.getHeight(null);
        if (paintType == ImageScalingHelper.PaintType.CENTER) {
            graphics.drawImage(image, i + (n - width) / 2, j + (n2 - height) / 2, null);
        }
        else if (paintType == ImageScalingHelper.PaintType.TILE) {
            int n9 = 0;
            for (int a = j + n2; j < a; j += height - n9, n9 = 0) {
                int n10 = 0;
                for (int a2 = i + n; i < a2; i += width - n10, n10 = 0) {
                    int min = Math.min(a2, i + width - n10);
                    int min2 = Math.min(a, j + height - n9);
                    graphics.drawImage(image, i, j, min, min2, n10, n9, n10 + min - i, n9 + min2 - j, null);
                }
            }
        }
        else {
            int n4 = empty_INSETS.top;
            int left = empty_INSETS.left;
            int bottom = empty_INSETS.bottom;
            int n5 = empty_INSETS.right;
            int n6 = empty_INSETS2.top;
            int n7 = empty_INSETS2.left;
            int bottom2 = empty_INSETS2.bottom;
            int right = empty_INSETS2.right;
            if (n4 + bottom > height) {
                n6 = (bottom2 = (bottom = (n4 = Math.max(0, height / 2))));
            }
            if (left + n5 > width) {
                right = (n7 = (left = (n5 = Math.max(0, width / 2))));
            }
            if (n6 + bottom2 > n2) {
                bottom2 = (n6 = Math.max(0, n2 / 2 - 1));
            }
            if (n7 + right > n) {
                right = (n7 = Math.max(0, n / 2 - 1));
            }
            int n8 = paintType == ImageScalingHelper.PaintType.PAINT9_STRETCH;
            if ((n3 & 0x200) != 0x0) {
                n3 = (0x1FF & ~n3);
            }
            if ((n3 & 0x8) != 0x0) {
                drawChunk(image, graphics, (boolean)n8, i, j + n6, i + n7, j + n2 - bottom2, 0, n4, left, height - bottom, false);
            }
            if ((n3 & 0x1) != 0x0) {
                drawImage(image, graphics, i, j, i + n7, j + n6, 0, 0, left, n4);
            }
            if ((n3 & 0x2) != 0x0) {
                drawChunk(image, graphics, (boolean)n8, i + n7, j, i + n - right, j + n6, left, 0, width - n5, n4, true);
            }
            if ((n3 & 0x4) != 0x0) {
                drawImage(image, graphics, i + n - right, j, i + n, j + n6, width - n5, 0, width, n4);
            }
            if ((n3 & 0x20) != 0x0) {
                drawChunk(image, graphics, (boolean)n8, i + n - right, j + n6, i + n, j + n2 - bottom2, width - n5, n4, width, height - bottom, false);
            }
            if ((n3 & 0x40) != 0x0) {
                drawImage(image, graphics, i + n - right, j + n2 - bottom2, i + n, j + n2, width - n5, height - bottom, width, height);
            }
            if ((n3 & 0x80) != 0x0) {
                drawChunk(image, graphics, (boolean)n8, i + n7, j + n2 - bottom2, i + n - right, j + n2, left, height - bottom, width - n5, height, true);
            }
            if ((n3 & 0x100) != 0x0) {
                drawImage(image, graphics, i, j + n2 - bottom2, i + n7, j + n2, 0, height - bottom, left, height);
            }
            if ((n3 & 0x10) != 0x0) {
                drawImage(image, graphics, i + n7, j + n6, i + n - right, j + n2 - bottom2, left, n4, width - n5, height - bottom);
            }
        }
        return;
    }
    
    private static void drawChunk(Image image, Graphics graphics, boolean b, int n, int n2, int a, int a2, int n3, int n4, int n5, int n6, boolean b2) {
        if (a - n <= 0 || a2 - n2 <= 0 || n5 - n3 <= 0 || n6 - n4 <= 0) {
            return;
        }
        if (b) {
            graphics.drawImage(image, n, n2, a, a2, n3, n4, n5, n6, null);
        }
        else {
            int n7 = n5 - n3;
            int n8 = n6 - n4;
            int n9;
            if (b2) {
                n9 = 0;
            }
            else {
                n7 = 0;
                n9 = n8;
            }
            while (n < a && n2 < a2) {
                int min = Math.min(a, n + n7);
                int min2 = Math.min(a2, n2 + n8);
                graphics.drawImage(image, n, n2, min, min2, n3, n4, n3 + min - n, n4 + min2 - n2, null);
                n += n7;
                n2 += n9;
            }
        }
        return;
    }
    
    private static void drawImage(Image image, Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6, int n7, int n8) {
        if (n3 - n <= 0 || n4 - n2 <= 0 || n7 - n5 <= 0 || n8 - n6 <= 0) {
            return;
        }
        graphics.drawImage(image, n, n2, n3, n4, n5, n6, n7, n8, null);
        return;
    }
    
    static {
        EMPTY_INSETS = new Insets(0, 0, 0, 0);
    }
    
    enum PaintType
    {
        CENTER, 
        TILE, 
        PAINT9_STRETCH, 
        PAINT9_TILE;
    }
}
